@@ -72,13 +72,15 @@ def code_to_rest_string(
     **options
 ):
 
+    lexer = get_lexer(code=code_str, **options)
+    if not lexer:
+        raise ValueError("Unable to determine a lexer for this string.")
+
     # Use a StringIO to capture writes into a string.
     output_rst = StringIO()
     # Include a header containing some `CodeChat style`. Don't put this in a separate ``.js`` file, since docutils doesn't have an easy way to include it.
     output_rst.write(rest_codechat_style)
-    ast_syntax_error, classified_lines = source_lexer(
-        code_str, get_lexer(code=code_str, **options)
-    )
+    ast_syntax_error, classified_lines = source_lexer(code_str, lexer)
     if ast_syntax_error:
         output_rst.write(".. error:: {}\n\n".format(ast_syntax_error))
     _generate_rest(classified_lines, output_rst)
@@ -207,6 +209,8 @@ def html_static_path():
 rest_codechat_style = ".. raw:: html\n\n " + codechat_style + "\n\n"
 
 
+# .. _Converting_classified_code_to_reST:
+#
 # Converting classified code to reST
 # ==================================
 # Approach
@@ -391,7 +395,10 @@ rest_codechat_style = ".. raw:: html\n\n " + codechat_style + "\n\n"
 # Note that mixing code and comments is hard: reST will still apply some of
 # its parsing rules to an inline code block or inline literal, meaning
 # that leading or trailing spaces and backticks will not be preserved,
-# instead parsing incorrectly. For example ::
+# instead parsing incorrectly. For example,
+#
+# .. code:: rest
+#   :number-lines:
 #
 #    :code:` Testing `
 #
@@ -558,25 +565,36 @@ class _FencedCodeBlock(CodeBlock):
         # Now, process the resulting contents as a code block.
         nodeList = CodeBlock.run(self)
 
-        # Sphinx fix: if the current `highlight
-        # <http://sphinx-doc.org/markup/code.html>`_ language is ``python``,
-        # "Normal Python code is only highlighted if it is parseable" (quoted
-        # from the previous link). This means code snippets, such as
-        # ``def foo():`` won't be highlighted: Python wants ``def foo(): pass``,
-        # for example. To get around this, setting the ``highlight_args`` option
-        # "force"=True skips the parsing. I found this in
-        # ``Sphinx.highlighting.highlight_block`` (see the ``force`` argument)
-        # and in ``Sphinx.writers.html.HTMLWriter.visit_literal_block``, where
-        # the ``code-block`` directive (which supports fragments of code, not
-        # just parseable code) has ``highlight_args['force'] = True`` set. This
-        # should be ignored by docutils, so it's done for both Sphinx and
-        # docutils. **Note:** This is based on examining Sphinx 1.3.1 source
-        # code.
-        #
-        # Note that the nodeList returned by the CodeBlock directive contains
-        # only a single ``literal_block`` node. The setting should be applied to
-        # it.
-        nodeList[0]["highlight_args"] = {"force": True}
+        highlight_args = nodeList[0].setdefault("highlight_args", {})
+        highlight_args.update(
+            {
+                # Sphinx fix: if the current `highlight
+                # <http://sphinx-doc.org/markup/code.html>`_ language is ``python``,
+                # "Normal Python code is only highlighted if it is parseable" (quoted
+                # from the previous link). This means code snippets, such as
+                # ``def foo():`` won't be highlighted: Python wants ``def foo(): pass``,
+                # for example. To get around this, setting the ``highlight_args`` option
+                # "force"=True skips the parsing. I found this in
+                # ``Sphinx.highlighting.highlight_block`` (see the ``force`` argument)
+                # and in ``Sphinx.writers.html.HTMLWriter.visit_literal_block``, where
+                # the ``code-block`` directive (which supports fragments of code, not
+                # just parseable code) has ``highlight_args['force'] = True`` set. This
+                # should be ignored by docutils, so it's done for both Sphinx and
+                # docutils. **Note:** This is based on examining Sphinx 1.3.1 source
+                # code.
+                #
+                # Note that the nodeList returned by the CodeBlock directive contains
+                # only a single ``literal_block`` node. The setting should be applied to
+                # it.
+                "force": True,
+                # The ``HTMLFormatter``, one of the `Pygments formatters <https://pygments.org/docs/formatters/#formatter-classes>`_, supports the ``lineanchors`` option, which adds a unique ID to each formatted line. Enable this for future use with ctags.
+                "lineanchors": "CodeChat",
+                # To get useful results, line numbers must be accurate; otherwise, they restart at 1 for each block. See `_SetLine`_ for details on how to extract the current line number.
+                "linenostart": self.state_machine.input_lines.items[
+                    self.state_machine.line_offset
+                ][1],
+            }
+        )
 
         return nodeList
 
@@ -767,7 +785,7 @@ class _CodeInclude(Directive):
             include_file = io.FileInput(
                 source_path=path, encoding=encoding, error_handler=e_handler
             )
-        except UnicodeEncodeError as error:
+        except UnicodeEncodeError:
             raise self.severe(
                 u'Problems with "%s" directive path:\n'
                 'Cannot encode input file path "%s" '
