@@ -44,11 +44,13 @@ from typing import Dict
 # Third-party imports
 # -------------------
 import sphinx
-import sphinx.util
+from sphinx.application import Sphinx
+from sphinx.config import Config
+import sphinx.io
 import sphinx.project
+import sphinx.util
 from sphinx.util import path_stabilize
 from sphinx.util.osutil import SEP, relpath
-import sphinx.io
 
 # The exception ``FiletypeNotFoundError`` was `deprecated in Sphinx v2.4.0 <https://www.sphinx-doc.org/en/master/extdev/deprecated.html>`_ by moving it from ``sphinx.io`` to ``sphinx.errors``.
 if sphinx.version_info[:3] >= (2, 4, 0):
@@ -59,12 +61,47 @@ import pygments.util
 
 # Local application imports
 # -------------------------
-from .CodeToRest import code_to_rest_string, get_lexer, add_highlight_language
+from .CodeToRest import code_to_rest_string, add_highlight_language
 from .CodeToMarkdown import code_to_markdown_string
 from .CommentDelimiterInfo import SUPPORTED_GLOBS
+from .SourceClassifier import get_lexer
 from . import __version__
 
 
+# Utility
+# =======
+#
+# .. _exclude_small_files:
+#
+# exclude_small_files
+# -------------------
+# Python requires ``__init__.py`` files; these are often small or even empty. Provide a function to exclude these from the docs in order to reduce noise. Invoke this from a ``setup`` function in a Sphinx extension.
+#
+# Therefore, this function excludes small files matching the given glob from a Sphinx build.
+def exclude_small_files(
+    # The Sphinx application object.
+    app_: Sphinx,
+    # A `glob pattern <https://docs.python.org/3/library/pathlib.html#pathlib.Path.glob>`_ specifying which files should be excluded if they are empty.
+    pattern: str,
+    # Optional; the maximum size of an ignorable file, in bytes. Defaults to 0.
+    max_size: int = 0,
+):
+    # This returns a function which will be called by the `config-inited`_ event.
+    def excluder(app: Sphinx, config: Config):
+        # The path must start in the `srcdir <https://www.sphinx-doc.org/en/master/extdev/appapi.html#sphinx.application.Sphinx.srcdir>`_.
+        root_path = Path(app.srcdir)
+        # This is slightly inefficient, since it doesn't use the existing excludes to avoid searching already-excluded values.
+        app.config.exclude_patterns += [  # type: ignore
+            # Paths must be relative to the srcdir.
+            x.relative_to(root_path).as_posix()
+            for x in root_path.glob(pattern)
+            if x.stat().st_size <= max_size
+        ]
+
+    # Connect this to the `config-inited <https://www.sphinx-doc.org/en/master/extdev/appapi.html#event-config-inited>`_ Sphinx event.
+    app_.connect("config-inited", excluder)
+
+
 # source-read event
 # =================
 # Create a logger for issuing warnings during the build process.
@@ -163,8 +200,8 @@ def is_markdown_docname(
 # --------------
 # For source files, make their docname the same as the file name; for reST
 # files, allow Sphinx to strip off the extension as before. This patch
-# accomplishes this. It comes from ``sphinx.project.Project``, line 46 and
-# following in Sphinx 2.0.1.
+# accomplishes this. It comes from ``sphinx.project.Project``, line 70 and
+# following in Sphinx 3.4.3.
 def _path2doc(self, filename):
     # type: (str) -> str
     """Return the docname for the filename if the file is document.
@@ -191,13 +228,18 @@ def _path2doc(self, filename):
 
 sphinx.project.Project.path2doc = _path2doc
 
+# Avoid recomputing the value of this variable by defining it globally.
+source_suffixpatterns = None
 
 # Return True if the provided filename is a source code language CodeChat supports.
 def is_supported_language(filename):
     # type: (str) -> bool
-    source_suffixpatterns = SUPPORTED_GLOBS | set(
-        _config.CodeChat_lexer_for_glob.keys()
-    )
+    # Initialize this if necessary.
+    global source_suffixpatterns
+    if not source_suffixpatterns:
+        source_suffixpatterns = SUPPORTED_GLOBS | set(
+            _config.CodeChat_lexer_for_glob.keys()
+        )
     path_filename = Path(filename)
     for source_suffixpattern in source_suffixpatterns:
         if path_filename.match(source_suffixpattern):
@@ -210,7 +252,7 @@ def is_supported_language(filename):
 # Next, the way docnames get transformed back to a full path needs to be fixed
 # for source files. Specifically, a docname might be the source file, without
 # adding an extension. This code comes from ``sphinx.project.Project`` of Sphinx
-# 2.0.1.
+# 3.4.3.
 def _doc2path(self, docname, basedir=True):
     # type: (str, bool) -> str
     """Return the filename for the document name.
@@ -260,11 +302,11 @@ def _get_filetype(source_suffix: Dict[str, str], filename: str) -> str:
         raise FiletypeNotFoundError
 
 
-# The function ``sphinx.io.get_filetype`` was `deprecated in Sphinx v2.4.0`_ by moving it to ``sphinx.util.get_filetype``.
-if sphinx.version_info[:3] >= (2, 4, 0):
+# The function ``sphinx.io.get_filetype`` was `deprecated in Sphinx v2.4.0`_ by moving it to ``sphinx.util.get_filetype``. Per the `where to patch <https://docs.python.org/3/library/unittest.mock.html#where-to-patch>`_ docs, patch this where the ``get_filetype`` function is used, not where it's defined. It's used in ``sphinx.io`` before and after deprecation; it's used in the deprecation machinery otherwise.
+SPHINX_VERSION = sphinx.version_info[:3]
+if SPHINX_VERSION >= (2, 4, 0) and SPHINX_VERSION < (4, 0, 0):
     # Sphinx uses ``sphinx.deprecation._ModuleWrapper`` to perform deprecation. In ``sphinx.io``, we need to monkeypatch inside it, hence the ``_module`` (a member of the ``_ModuleWrapper``).
     sphinx.io._module.get_filetype = _get_filetype
-    sphinx.util.get_filetype = _get_filetype
 else:
     sphinx.io.get_filetype = _get_filetype
 
